diff --git a/common/lib/capa/capa/responsetypes.py b/common/lib/capa/capa/responsetypes.py
index 2de34dbac5..d8703a4e2f 100644
--- a/common/lib/capa/capa/responsetypes.py
+++ b/common/lib/capa/capa/responsetypes.py
@@ -1854,7 +1854,7 @@ class AnnotationResponse(LoncapaResponse):
response_tag = 'annotationresponse'
allowed_inputfields = ['annotationinput']
max_inputfields = 1
- default_scoring = {'incorrect': 0, 'partial': 1, 'correct': 2 }
+ default_scoring = {'incorrect': 0, 'partially-correct': 1, 'correct': 2 }
def setup_response(self):
xml = self.xml
self.scoring_map = self._get_scoring_map()
diff --git a/common/lib/capa/capa/templates/annotationinput.html b/common/lib/capa/capa/templates/annotationinput.html
index 23579b20c8..bfbce08a0f 100644
--- a/common/lib/capa/capa/templates/annotationinput.html
+++ b/common/lib/capa/capa/templates/annotationinput.html
@@ -21,11 +21,11 @@
% for option in options:
% if all([c == 'correct' for c in option['choice'], status]):
-
- % elif all([c == 'partial' for c in option['choice'], status]):
- P
+
+ % elif all([c == 'partially-correct' for c in option['choice'], status]):
+
% elif all([c == 'incorrect' for c in option['choice'], status]):
-
+
% endif
diff --git a/common/lib/capa/capa/inputtypes.py b/common/lib/capa/capa/inputtypes.py
index 0531a59e3c..956d82bd94 100644
--- a/common/lib/capa/capa/inputtypes.py
+++ b/common/lib/capa/capa/inputtypes.py
@@ -950,15 +950,17 @@ class AnnotationInput(InputTypeBase):
Annotation Exercise
- They are the ones who, at the public assembly, had put savage derangement [atē] into my thinking [phre
-nes] |89 on that day when I myself deprived Achilles of his honorific portion [geras]
- Agamemnon says that atē or ‘derangement’ was the cause of his actions: why could Zeus say the same thing?
+
+ They are the ones who, at the public assembly, had put savage derangement [ate] into my thinking
+ [phrenes] |89 on that day when I myself deprived Achilles of his honorific portion [geras]
+
+ Agamemnon says that ate or 'derangement' was the cause of his actions: why could Zeus say the same thing?Type a commentary below:Select one or more tags:
-
-
-
+
+
+